<?php

namespace Ems\Logic\ProcessamentoSolicitacao;

use Ems\Util\Utils;
use Util\{ DateUtil, NovoCodigo, Repositories };

class ProcessamentoSolicitacaoFerias extends ProcessamentoSolicitacao {
    
    public function efetivar() {
        $itens = $this->getItensAssociativeArray();
        
        $nrferias           = $itens['NRFERIAS']   ?? null;
        $qtdiasferias       = $itens['QTDIASFERIAS']   ?? null;
        $qtdiasabonoferias  = $itens['QTDIASABONOFERI']   ?? 0;
        $dsgozoferias       = $itens['DSGOZOFERIAS']   ?? null;
        $idadiant13salar    = $itens['IDADIANT13SALAR']   ?? "N";
        $dtinigozoferias    = isset($itens['DTINIGOZOFERIAS']) ? DateUtil::getDataDeString(substr($itens['DTINIGOZOFERIAS'],0,10), DateUtil::FORMATO_BRASILEIRO, true) : null;
        $dtfimgozoferias    = isset($itens['DTFIMGOZOFERIAS']) ? DateUtil::getDataDeString(substr($itens['DTFIMGOZOFERIAS'],0,10), DateUtil::FORMATO_BRASILEIRO, true) : null;
        $dtatual            = DateUtil::getDataDeString(substr(date('d/m/Y'),0,10), DateUtil::FORMATO_BRASILEIRO, true);
        $nrorg              = Utils::getParamters()->getNrorg();
        $nrvinculom         = $this->getSolicitacao()->getNrvinculom();
        $observacao         = $this->getObservacaoComProtocolo($dsgozoferias);

        $ferias = Utils::getEntityManager()->getRepository(Repositories::FPA_FERIAS)->findBy(array("nrorg"=> $nrorg, "nrvinculom" => $nrvinculom, "nrferias" => $nrferias));

        $gozoFerias = Utils::getEntityManager()->getRepository(Repositories::FPA_GOZOFERIAS)->findBy(array("nrorg"=> $nrorg, "nrferias" => $nrferias));

        $diasFerias = 0;

        if($gozoFerias) {
            foreach ($gozoFerias as $gozoFeriasItem) {
                $inicioFerias = $gozoFeriasItem->getDtIniGozoFerias();
                $fimFerias = $gozoFeriasItem->getDtFimGozoFerias();
                $diasFerias += DateUtil::getQtdeDiasEntre($inicioFerias, $fimFerias) + 1;
            }
        }


        if(!$ferias) {
            throw new \Exception("Período de Férias não encontrado.");
        }

        $status = $ferias[0]->getIdControlFerias();
        $qtMaxFerias = $ferias[0]->getQtdiasMaxFe();
        $qtMaxFeriasAbono = $ferias[0]->getQtdiasMaxAbon();
        $dtIniAquisicao = $ferias[0]->getDtIniAquisicao();

        $proximaDtAquisitiva = DateUtil::adicionaIntervalo($ferias[0]->getDtfimAquisicao(), 1)->format('d/m/Y');
        $dtRetornoFerias = DateUtil::getDataDeString(substr(DateUtil::adicionaIntervalo($dtfimgozoferias, 1)->format('d/m/Y'),0,10), DateUtil::FORMATO_BRASILEIRO, true);


        if($status != "ADQUIRIDO" && $status != "GOZADO_PARCIAL") {
            throw new \Exception("Colaborador não possui férias com status ADQUIRIDO. Só poderá gozar férias a partir do dia '$proximaDtAquisitiva'. Favor Alterar.");
        }

        if($qtdiasferias + $diasFerias > $qtMaxFerias) {
            $limiteFeria = max(0, $qtMaxFerias - $diasFerias);
            //throw new \Exception("Período de Férias solicitado irá gerar pagamento de FÉRIAS EM DOBRO, o limite de gozo das férias desse Colaborador é: '$limiteFeria'. Favor Alterar.");
        }

        if ($qtdiasabonoferias > $qtMaxFeriasAbono) {
            throw new \Exception("O limite de abono de férias para esse Colaborador é: '$qtMaxFeriasAbono'. Favor Alterar.");
        }

        $dtInicioAquisitivoMenorQueGozo = DateUtil::getDataDeString(substr($dtinigozoferias,0, 10),DateUtil::FORMATO_BRASILEIRO, true)->format('Y/m/d') < $dtIniAquisicao->format('Y/m/d');

        if($dtInicioAquisitivoMenorQueGozo) {
            throw new \Exception("A data de início do gozo das férias não pode ser anterior à data de início da aquisição.");
        }

        $fpaGozoFerias = Repositories::FPA_GOZOFERIAS;
        $fpaGozoFerias = new $fpaGozoFerias;
        $fpaGozoFerias->setNrorg($nrorg);
        $fpaGozoFerias->setNrferias($nrferias);
        $fpaGozoFerias->setQtdiasferias($qtdiasferias);
        $fpaGozoFerias->setQtdiasabonoferi($qtdiasabonoferias);
        $fpaGozoFerias->setDtinigozoferias($dtinigozoferias);
        $fpaGozoFerias->setDtfimgozoferias($dtfimgozoferias);
        $fpaGozoFerias->setDtretornoferias($dtRetornoFerias);
        $fpaGozoFerias->setDsgozoferias($observacao);
        $fpaGozoFerias->setIdadiant13salar($idadiant13salar);
        $fpaGozoFerias->setDtinclusao(DateUtil::getDataAtual(false));
        $fpaGozoFerias->setDtultatu($dtatual);;
        $fpaGozoFerias->setNrorginclusao(Utils::getParamters()->getNrorg());
        $fpaGozoFerias->setNrorgultatu(Utils::getParamters()->getNrorg());
        $fpaGozoFerias->setCdoperinclusao(Utils::getParamters()->getCdoperador());
        $fpaGozoFerias->setCdoperultatu(Utils::getParamters()->getCdoperador());
        $fpaGozoFerias->setNrgozoferias(NovoCodigo::geraCodigo(Utils::getParamters()->getNrorg(), 'FPA_GOZOFERIAS', 1, 12, true));
        Utils::getEntityManager()->persist($fpaGozoFerias);
        Utils::getEntityManager()->flush();
    }
    
    public function rejeitar() {}

}
