<?php

namespace Tests\IntegrationTests;

use Tests\Util;

class ApuracaoAdicionalNoturnoTest extends HcmServicesIntegrationTestCase {

    /**
     * Sobrescreve o metodo setUpBeforeClass da classe padrao de testes
     */
    public static function setUpBeforeClass(): void {
        parent::setUpBeforeClass();

        /* Apura o periodo de testes */

        $apuracaoService = Util::getInstanceManager()->getService('ApuracaoService');

        $apuracaoService->apurarPeriodo(
            Util::DEFAULT_PK, Util::DEFAULT_PK
        );
    }

    /**
     * Caso de Testes 1
     * Apuracao de periodo com o dia 24/01/2023 totalizando 6 horas de adicional noturno,
     * sem considerar considerar os intervalos realizados dentro da jornada
     */
    public function testCalculoAdicionalNoturnoSemConsiderarIntervalo() {
        $apuracaoService = Util::getInstanceManager()->getService('ApuracaoService');

        $apuracaoDia = $apuracaoService->getResumoDiaSituFreqVinculo(
            Util::DEFAULT_PK, '24/01/2023'
        );

        $calculosAdicNot = array_filter(
            $apuracaoDia, function ($item) {
                return $item['NRSITUFREQUENCIA'] == 9000
                    && round($item['QTREFAPURSITUFREQ'], 3) == round(6 * (60/52.5), 3);
            }
        );

        $existemCalculosAdicNot = !empty($calculosAdicNot) && count($calculosAdicNot) == 1;
        $this->assertTrue($existemCalculosAdicNot);
    }

    /**
     * Caso de Testes 2
     * Apuracao de periodo com o dia 25/01/2023 totalizando 04:50 horas de adicional noturno,
     * sem considerar considerar os intervalos realizados dentro da jornada
     */
    public function testCalculoAdicionalNoturnoSemConsiderarIntervalo2() {
        $apuracaoService = Util::getInstanceManager()->getService('ApuracaoService');

        $apuracaoDia = $apuracaoService->getResumoDiaSituFreqVinculo(
            Util::DEFAULT_PK, '25/01/2023'
        );

        $calculosAdicNot = array_filter(
            $apuracaoDia, function ($item) {
                return $item['NRSITUFREQUENCIA'] == 9000
                    && round($item['QTREFAPURSITUFREQ'], 3) == round(5 * (60/52.5), 3);
            }
        );

        $existemCalculosAdicNot = !empty($calculosAdicNot) && count($calculosAdicNot) == 1;
        $this->assertTrue($existemCalculosAdicNot);
    }

    /**
     * Caso de Testes 3
     * Apuracao de periodo com o dia 30/01/2023 totalizando 6 horas de adicional noturno,
     * considerando o tempo em intervalo o calculo de adicional tera que contabilizar 7 horas
     */
    public function testCalculoAdicionalNoturnoConsiderandoIntervalo() {
        $apuracaoService = Util::getInstanceManager()->getService('ApuracaoService');

        $apuracaoDia = $apuracaoService->getResumoDiaSituFreqVinculo(
            Util::DEFAULT_PK, '30/01/2023'
        );

        $calculosAdicNot = array_filter(
            $apuracaoDia, function ($item) {
                return $item['NRSITUFREQUENCIA'] == 9000
                    && round($item['QTREFAPURSITUFREQ'], 3) == round(7 * (60/52.5), 3);
            }
        );

        $existemCalculosAdicNot = !empty($calculosAdicNot) && count($calculosAdicNot) == 1;
        $this->assertTrue($existemCalculosAdicNot);
    }

    /**
     * Caso de Testes 4
     * Apuracao de periodo com o dia 31/01/2023 totalizando 04:55 de adicional noturno,
     * considerando o tempo em intervalo o calculo de adicional tera que contabilizar 06:05 (+01:10)
     */
    public function testCalculoAdicionalNoturnoConsiderandoIntervalo2() {
        $apuracaoService = Util::getInstanceManager()->getService('ApuracaoService');

        $apuracaoDia = $apuracaoService->getResumoDiaSituFreqVinculo(
            Util::DEFAULT_PK, '31/01/2023'
        );

        $calculosAdicNot = array_filter(
            $apuracaoDia, function ($item) {
                return $item['NRSITUFREQUENCIA'] == 9000
                    && round($item['QTREFAPURSITUFREQ'], 3) == round(6.083333333 * (60/52.5), 3);
            }
        );

        $existemCalculosAdicNot = !empty($calculosAdicNot) && count($calculosAdicNot) == 1;
        $this->assertTrue($existemCalculosAdicNot);
    }

    public static function createTestData(): void {
        $DEFAULT_PK = Util::DEFAULT_PK;
        $DEFAULT_ORG = Util::DEFAULT_ORG;

        $sqls = [
            // Parceiro de negocio vinculo
            "Insert into PARCNEGOCIO (NRPARCNEGOCIO,NRORG,CDSEGMER,NMPRINCIPALPARC,NMSECUNDARIPARC,DTNASCIFUNDPARC,NRINSCRICAOPARC,IDATIVO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,CDTIPOPARCPRINCIPAL,CDTIPOINSCRICAO,IDPESSOAFISICA,IDINSTITUICAO,DSDEPARTAMENTO,IDIDIOMA,CDATIVCLI,NRSEQTPATIVCLI,IDPARCFUNDIDO,CDOPERRESPONSAVEL,NRTPCLASSIFICAPARC,DSDIRLOGOMARCA,CDINSCESTA,CDINSCMUNI)
            values ({$DEFAULT_PK},{$DEFAULT_ORG},null,'VINCULO TESTES INTEGRACAO','VINCULO TESTES INTEGRACAO',to_date('01/01/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,'S',to_date('19/03/2020 15:55:13','DD/MM/RRRR HH24:MI:SS'),to_date('20/03/2020 17:30:15','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'987654321125',{$DEFAULT_ORG},'987654321125','PESSOA','CPF','S','N',null,null,null,null,'N',null,null,null,null,null)",

            // Pessoa
            "Insert into GPE_PESSOA (NRPESSOA,NRORG,NRPARCNEGOCIO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,DTESOCIAL,IDATIVO)
            values ({$DEFAULT_PK},{$DEFAULT_ORG},{$DEFAULT_PK},to_date('19/03/2020 15:55:13','DD/MM/RRRR HH24:MI:SS'),to_date('20/03/2020 17:30:15','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'987654321125',{$DEFAULT_ORG},'987654321125',null,'S')",

            // Historico pessoa
            "Insert into GPE_PESSOAH (NRPESSOAH,NRPESSOA,NRORG,DTMESCOMPETENC,NMPESSOA,DSPRONOMETRAT,DSAPELIDOPESS,DSPRINOMEPESS,DSULTNOMEPESS,DSNOMEMEIOPESS,CDESTACIVIL,NRCONDFISPES,NRANOCHEGAPAIS,NRDOCUESTRANG,IDPOSVISTOPERM,DTPERMAVISTO,IDPESNATURALIZA,DTNATURALIZAPES,NRCPFPESSOA,NRREGCTPSPES,NRCTPSPESSOA,NRSERIECTPSPES,SGUFCTPSPES,DTCTPSPESSOA,NRPISPASEPPES,DTINSCPISPASEP,NRINSCINSSPES,NRINSCISSPES,NRCERTNASCPES,NRCERTCASAPES,DTCASAPESSOA,IDISENTITUELEI,NRTITUELEIPES,NRSECAELEIPES,NRZONAELEIPES,NRCARTHABPES,DTHABCARTPES,DTVALHABCARTPES,DSCATEGHABCART,NRCATMILITARPE,NRCERTRESEPES,DSCATEGCERTRESE,DTCERTRESEPES,CDEXCERTRESEPES,NRCONSELHOREG,NRINSCRCONSREG,DTEXCONSREG,SGUFCONSREG,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,NRRACAPESSOA,IDGRUPSANGUPES,IDFATORRHPES,CDPAIS,SGESTADO,CDMUNICIPIO,DTNASCPESSOA,IDSEXOPESSOA,CDTPBAIXAPAG,NRRGPESSOA,CDEXRGPESSOA,SGUFRGPESSOA,DSLOCALEXRGPES,DTEXRGPESSOA,NRNACIONALID,NRGRAUINSTR,DSCOMPLCERTNASC,NRLIVROCERTNASC,NRFOLHACERTNASC,DSCAMINHOFOTO,IDPOSSUIFILHO,NRIDADEFILHO,DTINIVIGENCIA,DTFIMVIGENCIA,NRLIVROCERTCASA,NRFOLHACERTCASA,SGUFHABCARPES,DSEXPDOCESTR,NRCLASSESTRANG,NRCERTOBITO,DTCHEGADAPAIS,NRSUSPESSOA,NRNITPESSOA,DTADMISSAOPRE,CDRECIBOADMPRE,IDCOTAPCD,IDATIVO)
            values ({$DEFAULT_PK},{$DEFAULT_PK},{$DEFAULT_ORG},to_date('01/02/2019 00:00:00','DD/MM/RRRR HH24:MI:SS'),'VINCULO TESTES INTEGRACAO',null,null,'VINCULO','INTEGRACAO','TESTES','S','1',null,null,null,null,null,null,'76276568007',null,null,null,null,null,null,null,null,null,null,null,null,'N','111111111111','0083','026',null,null,null,null,null,'11111111111',null,to_date('25/09/2018 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,null,null,null,null,to_date('18/02/2019 15:34:06','DD/MM/RRRR HH24:MI:SS'),to_date('19/02/2019 18:24:11','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'102512534784',{$DEFAULT_ORG},'000125241187','2',null,null,'0055','MG','4123',to_date('03/07/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),'M',null,'18087835','PCMG','MG','BELO HORIZONTE',to_date('09/11/2015 00:00:00','DD/MM/RRRR HH24:MI:SS'),'1','7',null,null,null,null,'N',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'S')",

            // Vinculo
            "Insert into GPE_VINCULOM (NRVINCULOM,NRPESSOA,NRORG,DTADMISSAOVINC,DTRESCISAOVINC,CDMATRICULA,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,NRTIPOVINCULOM,NRVINCULOEMPREG,NRTPADMISSAO,NRTPDEMISSAO,DTOPCAOFGTS,DTAPOSENTAFGTS,DTPRIMADMISSAO,NMVINCULOM,NRMOTIVORESC,DSOBSRESCISAO,DTAVISOPREVIO,NRDIASCONTRATOEXP,NRDIASCONTRATOEXPPRO,DTEXAMEMEDICO,DTAVISOTRCT,DSLIVROADMISSAO,IDSEGDESEMPVINC,NRDIASAPURVALES,NRTPAVIPRE,DTENTREGAEPI,DSOBSERVACAORESCISAO,IDVERIFICARESCISAO,IDTPREINTEGRACAO,NRPROCJUD,NRLEIANISTIA,IDPAGTOJUIZO,DTRETORNO,DTEFEITOFINANCEIRO,OBSREINTEGRACAO,DTCANCAVIPRE,NRMOTIVOCANCAP,DSOBSCANCAVIPRE,DTESOCIAL,DTVENCCONTREXPER,NRCLAUSASSECURAT,NRMOTIVOADMISSAO,NRVINCULOMSUBST,IDATIVO)
            values ({$DEFAULT_PK},{$DEFAULT_PK},{$DEFAULT_ORG},to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_PK},to_date('24/07/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('25/07/2023 11:37:34','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'102512535894',{$DEFAULT_ORG},'102512535894','1','1','2',null,to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),'VINCULO TESTES INTEGRACAO',null,null,null,null,null,to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,null,'N',null,null,null, EMPTY_CLOB(),null,null,null,null,'S',null,null,null,null,null,null,null,null,null,null,'0','S')",

            // Historico vinculo
            "Insert into GPE_VINCULOH (NRVINCULOH,NRVINCULOM,NRSITUFUNCM,NRCARGO,NRESCALATRABM,NRORG,DTMESCOMPETENC,IDCONTRIBUISIND,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,NRDEPENDIR,NRDEPENDSFAM,DTBASEFERIAS,IDREMUNERACAO,IDTPPAGAMENTO,NRESTRUTLEGAL,NRESTRUTGEREN,NRTPMODALIDSAL,IDMULTVINC,NRFUNCAO,CDCONTRIBINDIVIDUAL,NRTPMOVTRANSFM,DTFIMCONTRDETERMIN,NRESTRUTSIND,CONFIDENCIAL,NRDIASAPURVALES,NRTURNO,NRTPREGIMEPREV,IDASSOCSINDICATO,CDMATRICULAESOCIAL,NRFAIXA,IDPAGPROPFER13,NRAGENTENOCIVO,IDPARTARTCLT,IDATIVO)
            values ({$DEFAULT_PK},{$DEFAULT_PK},'1','1',null,{$DEFAULT_ORG},to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),'NUNCA',to_date('24/07/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('25/07/2023 11:38:15','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'102512535894',{$DEFAULT_ORG},'102512535894',null,null,to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,'MENSAL',null,null,'1','UNICO',null,null,null,null,null,'N',null,null,null,'N',null,null,'N',null,null,'S')",

            // Escala 1
            "Insert into GPE_ESCALATRABM (NRESCALATRABM,NRORG,DTINIVIGENCIA,DTFIMVIGENCIA,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,IDATIVO)
            values ({$DEFAULT_PK},{$DEFAULT_ORG},to_date('01/01/2000 16:36:37','DD/MM/RRRR HH24:MI:SS'),null,to_date('18/03/2015 11:52:56','DD/MM/RRRR HH24:MI:SS'),to_date('09/10/2017 16:36:37','DD/MM/RRRR HH24:MI:SS'),'1','000000000002',{$DEFAULT_ORG},'000000003541','S')",

            // Historico Escala 1
            "Insert into GPE_ESCALATRABH (NRESCALATRABH,NRESCALATRABM,NRORG,DTMESCOMPETENC,NMESCALATRABH,QTHRESCALATRABH,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,QTHRSEMESCTRABH,PRIENTRADA,PRISAIDA,SEGENTRADA,SEGSAIDA,DESCANSOSEMANAL,NRDIASAPURVALES,IDEXIGEAUTHORAEXTRA,QTHRLIMITESEPHEXTRA,IDTURNOEXTRAFERIADO,IDMANTEMPERCVIRADA,IDATRASOSOPRIMARC,IDPROJETAINTERVALO,QTHRPROJETAINTERVALO,IDDESCINTERVALOFOLGA,IDDESCINTERVALOFERIADO,IDDESCINTERVALOSABADO,IDTURNOINTERVALOEXTRA,IDHEXTRANMARCINTERV,HRINIPERIODONOTURNO,HRFIMPERIODONOTURNO,IDGERAMARCVIRADADIA,IDADCNOTURNOINTERVALO,IDCOMPENSAATRASO,IDATIVO,NRTPJORNADA,NRTPINTERVALO,NRDIAINIAPUR,NRDIAFINAPUR,IDUTAPURATEST,IDUTAPURADSR,IDFALTASREFLEXO,IDNAOCONTROLAJORNADA,QTHRSEMENAGEREN,QTHRESCALAGEREN,IDGERBENFER,QTHRMAXHRTRAB,NRSITFREQMAXHRTRAB,IDHORNOTURNO,VRACRESCADNOTURNO,IDUTAPURATESTBENEF)
            values ({$DEFAULT_PK},{$DEFAULT_PK},{$DEFAULT_ORG},to_date('01/01/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),'Escala Teste Integração 1','6.666666',to_date('09/10/2017 16:36:37','DD/MM/RRRR HH24:MI:SS'),to_date('28/06/2022 16:28:56','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'000000003541','1','1','40','08:00','12:00','13:00','17:00','SAB/DOM',null,'N','0000','N','S','N','N','0100','S','S','S','N','S','2200','0500','N','N','S','S','6','3',null,null,'N','N','N','N',null,null,'N',null,null,'N',null,'N')",

            // Escala 2
            "Insert into GPE_ESCALATRABM (NRESCALATRABM,NRORG,DTINIVIGENCIA,DTFIMVIGENCIA,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,IDATIVO)
            values ({$DEFAULT_PK}-1,{$DEFAULT_ORG},to_date('01/01/2000 16:36:37','DD/MM/RRRR HH24:MI:SS'),null,to_date('18/03/2015 11:52:56','DD/MM/RRRR HH24:MI:SS'),to_date('09/10/2017 16:36:37','DD/MM/RRRR HH24:MI:SS'),'1','000000000002',{$DEFAULT_ORG},'000000003541','S')",

            // Historico Escala 2
            "Insert into GPE_ESCALATRABH (NRESCALATRABH,NRESCALATRABM,NRORG,DTMESCOMPETENC,NMESCALATRABH,QTHRESCALATRABH,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,QTHRSEMESCTRABH,PRIENTRADA,PRISAIDA,SEGENTRADA,SEGSAIDA,DESCANSOSEMANAL,NRDIASAPURVALES,IDEXIGEAUTHORAEXTRA,QTHRLIMITESEPHEXTRA,IDTURNOEXTRAFERIADO,IDMANTEMPERCVIRADA,IDATRASOSOPRIMARC,IDPROJETAINTERVALO,QTHRPROJETAINTERVALO,IDDESCINTERVALOFOLGA,IDDESCINTERVALOFERIADO,IDDESCINTERVALOSABADO,IDTURNOINTERVALOEXTRA,IDHEXTRANMARCINTERV,HRINIPERIODONOTURNO,HRFIMPERIODONOTURNO,IDGERAMARCVIRADADIA,IDADCNOTURNOINTERVALO,IDCOMPENSAATRASO,IDATIVO,NRTPJORNADA,NRTPINTERVALO,NRDIAINIAPUR,NRDIAFINAPUR,IDUTAPURATEST,IDUTAPURADSR,IDFALTASREFLEXO,IDNAOCONTROLAJORNADA,QTHRSEMENAGEREN,QTHRESCALAGEREN,IDGERBENFER,QTHRMAXHRTRAB,NRSITFREQMAXHRTRAB,IDHORNOTURNO,VRACRESCADNOTURNO,IDUTAPURATESTBENEF)
            values ({$DEFAULT_PK}-1,{$DEFAULT_PK}-1,{$DEFAULT_ORG},to_date('01/01/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),'Escala Teste Integração 2','6.666666',to_date('09/10/2017 16:36:37','DD/MM/RRRR HH24:MI:SS'),to_date('28/06/2022 16:28:56','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'000000003541','1','1','40','08:00','12:00','13:00','17:00','SAB/DOM',null,'N','0000','N','S','N','N','0100','S','S','S','N','S','2200','0500','N','S','S','S','6','3',null,null,'N','N','N','N',null,null,'N',null,null,'N',null,'N')",

            // Turno 1
            "Insert into GPE_TURNO (NRORG,NRTURNO,NRESCALATRABM,DTDATABASE,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,DSTURNO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},{$DEFAULT_PK},to_date('01/01/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),'S',{$DEFAULT_ORG},to_date('27/05/2015 10:49:24','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:49:24','DD/MM/RRRR HH24:MI:SS'),'7','Turno Testes Integração')",

            // Turno 2
            "Insert into GPE_TURNO (NRORG,NRTURNO,NRESCALATRABM,DTDATABASE,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,DSTURNO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-1,{$DEFAULT_PK}-1,to_date('01/01/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),'S',{$DEFAULT_ORG},to_date('27/05/2015 10:49:24','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:49:24','DD/MM/RRRR HH24:MI:SS'),'7','Turno Testes Integração 2')",

            // Horario 1
            "Insert into GPE_HORDIAM (NRORG,NRHORDIAM,DTINIVIGENCIA,DTFIMVIGENCIA,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,DTESOCIAL,CDINTEGRACAO,IDATIVO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},to_date('01/01/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,to_date('17/12/2019 11:26:34','DD/MM/RRRR HH24:MI:SS'),to_date('17/12/2019 11:28:28','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'000000000078',{$DEFAULT_ORG},'000000000078',null,null,'S')",

            // Historico Horario 1
            "Insert into GPE_HORDIAH (NRORG,NRHORDIAH,NRHORDIAM,DTMESCOMPETENC,NMHORDIAH,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,IDTIPOHORARIO,HRINICOLETAMARCACAO,IDATIVO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},{$DEFAULT_PK},to_date('01/01/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),'Horário Teste Integração 1',to_date('26/05/2015 14:51:52','DD/MM/RRRR HH24:MI:SS'),to_date('26/05/2015 14:51:52','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'7',{$DEFAULT_ORG},'7','N','0600','S')",

            // Horario 2
            "Insert into GPE_HORDIAM (NRORG,NRHORDIAM,DTINIVIGENCIA,DTFIMVIGENCIA,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,DTESOCIAL,CDINTEGRACAO,IDATIVO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-1,to_date('01/01/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,to_date('27/05/2015 10:15:46','DD/MM/RRRR HH24:MI:SS'),to_date('02/05/2017 12:18:17','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'7',{$DEFAULT_ORG},'000000000078',null,null,'S')",

            // Historico Horario 2
            "Insert into GPE_HORDIAH (NRORG,NRHORDIAH,NRHORDIAM,DTMESCOMPETENC,NMHORDIAH,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,IDTIPOHORARIO,HRINICOLETAMARCACAO,IDATIVO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-1,{$DEFAULT_PK}-1,to_date('01/01/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),'Horário Teste Integração 2',to_date('25/05/2015 18:19:44','DD/MM/RRRR HH24:MI:SS'),to_date('25/05/2015 18:19:44','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'7',{$DEFAULT_ORG},'7','F','0000','S')",

            // Intervalo Horario 1.1
            "Insert into GPE_INTERVALOSHORARIO (NRORG,NRINTERVALOHORARIO,NRHORDIAM,NRSEQINTERVHORARIO,HRENTRADA,HRTOLERAANTEENTRADA,HRTOLERAPOSTENTRADA,HRSAIDA,HRTOLERAANTESAIDA,HRTOLERAPOSTSAIDA,HRINICIONUCLEO,HRFIMNUCLEO,IDDIAOCORREENTRADA,IDDIAOCORRESAIDA,IDCTRLMARCENTRADA,IDCTRLMARCSAIDA,IDAJUSTEMARCENTRADA,IDAJUSTEMARCSAIDA,HRPROJETARINTERVALO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,DSINTERVALOPROJETADO,NRTPINTERVALO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},{$DEFAULT_PK},'1','2200','2200','2200','0100','0100','0100','2200','0100','DC','DA','N','N','N','N','0100','S',{$DEFAULT_ORG},to_date('26/05/2015 14:51:55','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('31/10/2018 18:21:07','DD/MM/RRRR HH24:MI:SS'),'000000001924','Almoço',null)",

            // Intervalo Horario 1.2
            "Insert into GPE_INTERVALOSHORARIO (NRORG,NRINTERVALOHORARIO,NRHORDIAM,NRSEQINTERVHORARIO,HRENTRADA,HRTOLERAANTEENTRADA,HRTOLERAPOSTENTRADA,HRSAIDA,HRTOLERAANTESAIDA,HRTOLERAPOSTSAIDA,HRINICIONUCLEO,HRFIMNUCLEO,IDDIAOCORREENTRADA,IDDIAOCORRESAIDA,IDCTRLMARCENTRADA,IDCTRLMARCSAIDA,IDAJUSTEMARCENTRADA,IDAJUSTEMARCSAIDA,HRPROJETARINTERVALO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,DSINTERVALOPROJETADO,NRTPINTERVALO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-1,{$DEFAULT_PK},'2','0200','0200','0200','0700','0700','0700','0200','0700','DA','DA','N','N','N','N',null,'S',{$DEFAULT_ORG},to_date('26/05/2015 14:52:25','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('31/10/2018 18:21:22','DD/MM/RRRR HH24:MI:SS'),'000000001924',null,null)",

            // Horario Turno 1.1
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},{$DEFAULT_PK},{$DEFAULT_PK}-1,'1','S',{$DEFAULT_ORG},to_date('27/05/2015 10:49:31','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:49:40','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 1.2
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-1,{$DEFAULT_PK},{$DEFAULT_PK}-1,'2','S',{$DEFAULT_ORG},to_date('27/05/2015 10:49:46','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:49:52','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 1.3
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-2,{$DEFAULT_PK},{$DEFAULT_PK},'3','S',{$DEFAULT_ORG},to_date('27/05/2015 10:49:57','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:50:13','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 1.4
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-3,{$DEFAULT_PK},{$DEFAULT_PK},'4','S',{$DEFAULT_ORG},to_date('27/05/2015 10:50:17','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('10/12/2015 11:31:02','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 1.5
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-4,{$DEFAULT_PK},{$DEFAULT_PK},'5','S',{$DEFAULT_ORG},to_date('27/05/2015 10:50:26','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:52:58','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 1.6
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-5,{$DEFAULT_PK},{$DEFAULT_PK},'6','S',{$DEFAULT_ORG},to_date('27/05/2015 10:53:10','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:53:15','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 1.7
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-6,{$DEFAULT_PK},{$DEFAULT_PK},'7','S',{$DEFAULT_ORG},to_date('27/05/2015 10:53:49','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:53:54','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 2.1
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-7,{$DEFAULT_PK}-1,{$DEFAULT_PK}-1,'1','S',{$DEFAULT_ORG},to_date('27/05/2015 10:49:31','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:49:40','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 2.2
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-8,{$DEFAULT_PK}-1,{$DEFAULT_PK}-1,'2','S',{$DEFAULT_ORG},to_date('27/05/2015 10:49:46','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:49:52','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 2.3
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-9,{$DEFAULT_PK}-1,{$DEFAULT_PK},'3','S',{$DEFAULT_ORG},to_date('27/05/2015 10:49:57','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:50:13','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 2.4
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-10,{$DEFAULT_PK}-1,{$DEFAULT_PK},'4','S',{$DEFAULT_ORG},to_date('27/05/2015 10:50:17','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('10/12/2015 11:31:02','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 2.5
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-11,{$DEFAULT_PK}-1,{$DEFAULT_PK},'5','S',{$DEFAULT_ORG},to_date('27/05/2015 10:50:26','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:52:58','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 2.6
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-12,{$DEFAULT_PK}-1,{$DEFAULT_PK},'6','S',{$DEFAULT_ORG},to_date('27/05/2015 10:53:10','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:53:15','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Horario Turno 2.7
            "Insert into GPE_HORARIOTURNO (NRORG,NRHORARIOTURNO,NRTURNO,NRHORDIAM,NRSEQHORARIO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,IDDIAVARIAVEL)
            values ({$DEFAULT_ORG},${DEFAULT_PK}-13,{$DEFAULT_PK}-1,{$DEFAULT_PK},'7','S',{$DEFAULT_ORG},to_date('27/05/2015 10:53:49','DD/MM/RRRR HH24:MI:SS'),'7',{$DEFAULT_ORG},to_date('27/05/2015 10:53:54','DD/MM/RRRR HH24:MI:SS'),'7','N')",

            // Alteracao de Escala 1
            "Insert into GPE_ALTEESCALA (NRORG,NRALTEESCALA,NRVINCULOM,DTINIESCALA,DTFIMESCALA,NRESCALATRABM,NRHORDIAM,NRMOTIVOESCALA,DSOBSERVACAO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,NRTURNO,QTHRLIMITESEPHEXTRA,IDATIVO,IDCONTJORNADA)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},{$DEFAULT_PK},to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('29/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_PK},null,null,null,to_date('07/02/2023 15:28:12','DD/MM/RRRR HH24:MI:SS'),to_date('11/04/2023 13:18:58','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'987654321125',{$DEFAULT_ORG},'102512535894',{$DEFAULT_PK},null,'S',null)",

            // Alteracao de Escala 2
            "Insert into GPE_ALTEESCALA (NRORG,NRALTEESCALA,NRVINCULOM,DTINIESCALA,DTFIMESCALA,NRESCALATRABM,NRHORDIAM,NRMOTIVOESCALA,DSOBSERVACAO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,NRTURNO,QTHRLIMITESEPHEXTRA,IDATIVO,IDCONTJORNADA)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-1,{$DEFAULT_PK},to_date('30/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_PK}-1,null,null,null,to_date('07/02/2023 15:28:12','DD/MM/RRRR HH24:MI:SS'),to_date('11/04/2023 13:18:58','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'987654321125',{$DEFAULT_ORG},'102512535894',{$DEFAULT_PK}-1,null,'S',null)",

            // Ocorrencia de Complementa Trabalho
            "Insert into PTO_PROGOCORRENCIA (NRORG,NRPROGOCORRENCIA,NRVINCULOM,DTINICIOPROGOCOR,DTFIMPROGOCOR,IDDIASSEMANA,IDTIPODIACALENDARIO,IDTIPOHORARIO,NRMOTIVOOCORFREQ,NRHORDIAM,NRSITUFREQUENCIA,NRSITUFREQGATILHO,QTMINGATILHOPROGOCOR,QTMAXGATILHOPROGOCOR,VRCOEFICIENTEACRESCIMO,IDPROGOCORRENCIA,QTMINIMAPROGOCOR,QTMAXIMAPROGOCOR,DSOBSERVACAO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRTIPOPROGOCORRENCIA,NRMARCACAOPONTO,NRINTERVALOHORARIO,IDPROGOCORCONFIRMADA,CDOPERVERIFICADO,DSOBSERVACAORECUSA,HRPROJETARINTERVALONPROG,DSPATH,CDTABECDI,CDDIAGNOST,NRPESSOA)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},{$DEFAULT_PK},to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,'1111111',null,'N',null,null,null,null,null,null,null,null,null,null,null,'S',{$DEFAULT_ORG},to_date('01/01/2023 16:17:05','DD/MM/RRRR HH24:MI:SS'),null,null,null,null,'21',null,null,'S',null,null,null,null,null,null,null)",

            // Tipo de Apuracao
            "Insert into PTO_TIPOAPURACAOFREQ (NRTIPOAPURACAO,NRORG,NMTIPOAPURACAO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU)
            values ({$DEFAULT_PK},{$DEFAULT_ORG},'Apuração CLT - TI','S',{$DEFAULT_ORG},to_date('01/01/2023 12:49:46','DD/MM/RRRR HH24:MI:SS'),null,null,null,null)",

            // Tipo de Periodo
            "Insert into PTO_TIPOPERIODOAPURACAO (NRORG,NRTIPOPERIODOAPURACAO,NRTIPOVINCULOM,NRTIPOAPURACAO,DSTIPOPERIODOAPURACAO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},'1',{$DEFAULT_PK},'Apuração CLT - TI','S',{$DEFAULT_ORG},to_date('01/01/2023 12:58:03','DD/MM/RRRR HH24:MI:SS'),null,null,null,null)",

            // Periodo de Apuracao
            "Insert into PTO_PERIODOAPURACAO (NRORG,NRPERIODOAPURACAO,NRTIPOPERIODOAPURACAO,DTINICIALAPURACAO,DTFINALAPURACAO,IDPERIODOAPURACAO,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},{$DEFAULT_PK},to_date('21/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('20/02/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),'ABERTO','S',{$DEFAULT_ORG},to_date('01/01/2023 09:40:12','DD/MM/RRRR HH24:MI:SS'),null,null,null,null)",

            // Marcacao 1
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},{$DEFAULT_PK},to_date('23/01/2023 22:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('23/01/2023 22:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FC',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

            // Marcacao 2
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-1,{$DEFAULT_PK},to_date('24/01/2023 02:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('24/01/2023 02:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

            // Marcacao 3
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-2,{$DEFAULT_PK},to_date('24/01/2023 03:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('24/01/2023 03:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

            // Marcacao 4
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-3,{$DEFAULT_PK},to_date('24/01/2023 07:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('24/01/2023 07:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

            // Marcacao 5
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-4,{$DEFAULT_PK},to_date('24/01/2023 22:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('24/01/2023 22:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FC',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

            // Marcacao 6
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-5,{$DEFAULT_PK},to_date('25/01/2023 02:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('25/01/2023 02:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

            // Marcacao 7
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-6,{$DEFAULT_PK},to_date('25/01/2023 03:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('25/01/2023 03:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

            // Marcacao 8
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-7,{$DEFAULT_PK},to_date('25/01/2023 07:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('25/01/2023 07:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

            // Marcacao 9
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-8,{$DEFAULT_PK},to_date('25/01/2023 22:50:00','DD/MM/RRRR HH24:MI:SS'),to_date('25/01/2023 22:50:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FC',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

            // Marcacao 10
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-9,{$DEFAULT_PK},to_date('26/01/2023 02:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('26/01/2023 02:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

            // Marcacao 11
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-10,{$DEFAULT_PK},to_date('26/01/2023 03:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('26/01/2023 03:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

            // Marcacao 12
            "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-11,{$DEFAULT_PK},to_date('26/01/2023 04:50:00','DD/MM/RRRR HH24:MI:SS'),to_date('26/01/2023 04:50:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",

             // Marcacao 13
             "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
             values ({$DEFAULT_ORG},{$DEFAULT_PK}-12,{$DEFAULT_PK},to_date('30/01/2023 22:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('30/01/2023 22:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FC',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",
 
             // Marcacao 14
             "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
             values ({$DEFAULT_ORG},{$DEFAULT_PK}-13,{$DEFAULT_PK},to_date('31/01/2023 02:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('31/01/2023 02:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",
 
             // Marcacao 15
             "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
             values ({$DEFAULT_ORG},{$DEFAULT_PK}-14,{$DEFAULT_PK},to_date('31/01/2023 03:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('31/01/2023 03:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",
 
             // Marcacao 16
             "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
             values ({$DEFAULT_ORG},{$DEFAULT_PK}-15,{$DEFAULT_PK},to_date('31/01/2023 07:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('31/01/2023 07:00:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",
 
             // Marcacao 17
             "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
             values ({$DEFAULT_ORG},{$DEFAULT_PK}-16,{$DEFAULT_PK},to_date('31/01/2023 22:45:00','DD/MM/RRRR HH24:MI:SS'),to_date('31/01/2023 22:45:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FC',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",
 
             // Marcacao 18
             "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
             values ({$DEFAULT_ORG},{$DEFAULT_PK}-17,{$DEFAULT_PK},to_date('01/02/2023 02:30:00','DD/MM/RRRR HH24:MI:SS'),to_date('01/02/2023 02:30:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",
 
             // Marcacao 19
             "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
             values ({$DEFAULT_ORG},{$DEFAULT_PK}-18,{$DEFAULT_PK},to_date('01/02/2023 03:40:00','DD/MM/RRRR HH24:MI:SS'),to_date('01/02/2023 03:40:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",
 
             // Marcacao 20
             "Insert into GPE_MARCACAOPONTO (NRORG,NRMARCACAOPONTO,NRVINCULOM,DTHRMARCACAOPONTO,DTHRAJUSTADA,IDENQUADRAHORARIO,IDMARCDESPREZADA,IDDIAOCORRENCIA,DSJUSTIFICATIVA,IDATIVO,NRORGINCLUSAO,DTINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,DTULTATU,CDOPERULTATU,NRCOLETOR,IDFIXAENTSAID,IDREFERINTERVALO,IDNSRREP,QTHRSDIURNAS,QTHRSNOTURNAS,QTHRSEXTRAS,PERCHRSEXTRAS,IDTPHREXTRA,QTHRSEXTRAS2,PERCHRSEXTRAS2,IDTPHREXTRA2,QTHRSEXTRAS3,PERCHRSEXTRAS3,IDTPHREXTRA3,QTHRSEXTRAS4,PERCHRSEXTRAS4,IDTPHREXTRA4,QTHRSATRASOS,QTHRSCOMPENSAR,IDHRSCOMPENSAR,CDCNPJESTRUT,NMRAZSOCESTRUT,CDCAEPFESTRUT,CDCEIESTRUT,CDTICKETAUT,DSLATITUDE,DSLONGITUDE,DSPATHFOTO,IDEXIGEAPROVACAO)
             values ({$DEFAULT_ORG},{$DEFAULT_PK}-19,{$DEFAULT_PK},to_date('01/02/2023 04:50:00','DD/MM/RRRR HH24:MI:SS'),to_date('01/02/2023 04:50:00','DD/MM/RRRR HH24:MI:SS'),'S','N','FA',null,'S',null,to_date('01/01/2023 10:50:03','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_ORG},null,null,'24',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'N')",
        ];

        foreach ($sqls as $sql) {
            Util::executeStatementOnConnection($sql);
        }
    }

    public static function destroyTestData(): void {
        $DEFAULT_PK = Util::DEFAULT_PK;
        $DEFAULT_ORG = Util::DEFAULT_ORG;

        $connection = Util::getConnection();
        $connection->setAutoCommit(false);

        $sqls = [
            "Delete From PTO_ALTEBANCOHORAS Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From PTO_PROGOCORRENCIA Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From GPE_ALTEESCALA Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From PTO_RESUMOSITUFREQ Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From GPE_APURAFREQUENCIA Where NRORG = {$DEFAULT_ORG} And NRPERIODOAPURACAO = {$DEFAULT_PK}",
            "Delete From PTO_PERIODOAPURACAO Where NRORG = {$DEFAULT_ORG} And NRPERIODOAPURACAO = {$DEFAULT_PK}",
            "Delete From PTO_TIPOPERIODOAPURACAO Where NRORG = {$DEFAULT_ORG} And NRTIPOPERIODOAPURACAO = {$DEFAULT_PK}",
            "Delete From PTO_TIPOAPURACAOFREQ Where NRORG = {$DEFAULT_ORG} And NRTIPOAPURACAO = {$DEFAULT_PK}",
            "Delete From GPE_MARCACAOPONTO Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From PTO_ASSOCSITUFREQ Where NRORG = {$DEFAULT_ORG} And NRSITUFREQUENCIA in ({$DEFAULT_PK}, {$DEFAULT_PK}-1)",
            "Delete From PTO_SITUFREQPARAM Where NRORG = {$DEFAULT_ORG} And NRSITUFREQUENCIA in ({$DEFAULT_PK}, {$DEFAULT_PK}-1)",
            "Delete From PTO_SITUFREQUENCIA Where NRORG = {$DEFAULT_ORG} And NRSITUFREQUENCIA in ({$DEFAULT_PK}, {$DEFAULT_PK}-1)",
            "Delete From GPE_MOVIMENTACAO Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From GPE_VINCULOH Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From GPE_VINCULOM Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From GPE_PESSOAH Where NRORG = {$DEFAULT_ORG} And NRPESSOA = {$DEFAULT_PK}",
            "Delete From GPE_PESSOA Where NRORG = {$DEFAULT_ORG} And NRPESSOA = {$DEFAULT_PK}",
            "Delete From ESTRUTURAH Where NRORG = {$DEFAULT_ORG} And NRESTRUTURAM = {$DEFAULT_PK}",
            "Delete From ESTRUTURAM Where NRORG = {$DEFAULT_ORG} And NRESTRUTURAM = {$DEFAULT_PK}",
            "Delete From OCORCALENDARIO Where NRORG = {$DEFAULT_ORG} And NRCALENDARIO In ({$DEFAULT_PK},{$DEFAULT_PK}-1)",
            "Delete From CALENDARIO Where NRORG = {$DEFAULT_ORG} And NRCALENDARIO = {$DEFAULT_PK}",
            "Delete From PARCNEGOCIO Where NRORG = {$DEFAULT_ORG} And NRPARCNEGOCIO In ({$DEFAULT_PK},{$DEFAULT_PK}-1)",
            "Delete From GPE_INTERVALOSHORARIO Where NRORG = {$DEFAULT_ORG} And NRHORDIAM in ({$DEFAULT_PK},{$DEFAULT_PK}-1)",
            "Delete From GPE_HORARIOTURNO Where NRORG = {$DEFAULT_ORG} And NRTURNO In ({$DEFAULT_PK},{$DEFAULT_PK}-1)",
            "Delete From GPE_TURNO Where NRORG = {$DEFAULT_ORG} And NRTURNO In ({$DEFAULT_PK},{$DEFAULT_PK}-1)",
            "Delete From GPE_ESCALATRABH Where NRORG = {$DEFAULT_ORG} And NRESCALATRABH In ({$DEFAULT_PK},{$DEFAULT_PK}-1)",
            "Delete From GPE_ESCALATRABM Where NRORG = {$DEFAULT_ORG} And NRESCALATRABM In ({$DEFAULT_PK},{$DEFAULT_PK}-1)",
            "Delete From GPE_HORDIAH Where NRORG = {$DEFAULT_ORG} And NRHORDIAM in ({$DEFAULT_PK},{$DEFAULT_PK}-1,{$DEFAULT_PK}-2,{$DEFAULT_PK}-3)",
            "Delete From GPE_HORDIAM Where NRORG = {$DEFAULT_ORG} And NRHORDIAM in ({$DEFAULT_PK},{$DEFAULT_PK}-1,{$DEFAULT_PK}-2,{$DEFAULT_PK}-3)",
        ];

        foreach ($sqls as $sql) {
            $connection->executeStatement($sql);
        }

        $connection->commit();
    }
}
